@@ -1,11 +1,11 @@
 #' Full List of Emojis
 #'
 #' This data set is the heart of the emoji package. It contains various
-#' information regarding all the avaiable emojis as of v13.1.
+#' information regarding all the avaiable emojis as of v15.0.
 #'
-#' @source [Unicode® Full Emoji Charts v13.1](https://www.unicode.org/emoji/charts-13.1/full-emoji-list.html)
-#' @source [Unicode® Emoji Charts v13.1](https://www.unicode.org/emoji/charts-13.1/emoji-list.html)
-#' @source [Unicode® Emoji Ordering, v13.1](https://www.unicode.org/emoji/charts/emoji-ordering.txt)
+#' @source [Unicode® Full Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/full-emoji-list.html)
+#' @source [Unicode® Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/emoji-list.html)
+#' @source [Unicode® Emoji Ordering, v15.0](https://www.unicode.org/emoji/charts/emoji-ordering.txt)
 #' @source \url{https://github.com/github/gemoji}
 #' @source \url{https://github.com/muan/emojilib}
 #'
@@ -38,7 +38,7 @@
 #'   \item{keywords}{vector of aliases}
 #' }
 #'
-#' @seealso emoji_name emoji_keyboard
+#' @seealso emoji_name emoji_keyword
 "emojis"
 
 #' Emoji Names
@@ -51,15 +51,15 @@
 #' associated with them. Such as "grinning" and "grinning_face" leading to the
 #' same emoji.
 #'
-#' @source [Unicode® Full Emoji Charts v13.1](https://www.unicode.org/emoji/charts-13.1/full-emoji-list.html)
-#' @source [Unicode® Emoji Charts v13.1](https://www.unicode.org/emoji/charts-13.1/emoji-list.html)
-#' @source [Unicode® Emoji Ordering, v13.1](https://www.unicode.org/emoji/charts/emoji-ordering.txt)
+#' @source [Unicode® Full Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/full-emoji-list.html)
+#' @source [Unicode® Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/emoji-list.html)
+#' @source [Unicode® Emoji Ordering, v15.0](https://www.unicode.org/emoji/charts/emoji-ordering.txt)
 #' @source \url{https://github.com/github/gemoji}
 #' @source \url{https://github.com/muan/emojilib}
 #'
 #' @format named character vector with `r length(emoji_name)` elements
 #'
-#' @seealso emojis emoji_keyboard
+#' @seealso emojis emoji_keyword
 "emoji_name"
 
 #' Emoji Keywords
@@ -67,9 +67,9 @@
 #' This list contains information about which emojis are contained in which
 #' keywords.
 #'
-#' @source [Unicode® Full Emoji Charts v13.1](https://www.unicode.org/emoji/charts-13.1/full-emoji-list.html)
-#' @source [Unicode® Emoji Charts v13.1](https://www.unicode.org/emoji/charts-13.1/emoji-list.html)
-#' @source [Unicode® Emoji Ordering, v13.1](https://www.unicode.org/emoji/charts/emoji-ordering.txt)
+#' @source [Unicode® Full Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/full-emoji-list.html)
+#' @source [Unicode® Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/emoji-list.html)
+#' @source [Unicode® Emoji Ordering, v15.0](https://www.unicode.org/emoji/charts/emoji-ordering.txt)
 #' @source \url{https://github.com/github/gemoji}
 #' @source \url{https://github.com/muan/emojilib}
 #'
@@ -77,3 +77,25 @@
 #'
 #' @seealso emojis emoji_name
 "emoji_keyword"
+
+#' Emoji Modifiers
+#'
+#' This data set contains all the emojis with modifiers, their unmodified
+#' version as well as a list of the the modifiers.
+#'
+#' @source [Unicode® Full Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/full-emoji-list.html)
+#' @source [Unicode® Emoji Charts v15.0](https://www.unicode.org/emoji/charts-15.0/emoji-list.html)
+#' @source [Unicode® Emoji Ordering, v15.0](https://www.unicode.org/emoji/charts/emoji-ordering.txt)
+#' @source \url{https://github.com/github/gemoji}
+#' @source \url{https://github.com/muan/emojilib}
+#'
+#' @format tibble with `r ncol(emoji_modifiers)` columns and
+#' `nrow(emoji_modifiers)` rows
+#' \describe{
+#'   \item{emoji_modifiers}{character representation of the emoji with modifiers}
+#'   \item{emoji}{character representation of the emoji without modifiers}
+#'   \item{modifiers}{list of modifiers}
+#' }
+#'
+#' @seealso emojis emoji_name
+"emoji_modifiers"
